---
title: <span class="badge object-type-scalar"></span> BytesPerSecondIEC
---
# <span class="badge object-type-scalar"></span> BytesPerSecondIEC

Data rate: bytes/sec(IEC)

## Definition

```python
# Data rate: bytes/sec(IEC)
BytesPerSecondIEC: typing.Literal["binBps"] = "binBps"
```
